<?php
// $Id$
function reviewboard_notifications_email_configuration() {
  $form['workflow'] = array(
    '#type' => 'fieldset',
    '#title' => 'Workflow transition notifications',
  );
  $form['workflow']['instructions'] = array(
    '#prefix' => '<div>',
    '#value' => 'Select which notifications you would like to enable for each workflow state.',
    '#suffix' => '</div>',
  );
  $wid = workflow_get_workflow_for_type('review');
  $states = workflow_get_states($wid);
  array_shift($states);
  foreach ($states as $sid => $state) {
    $key = strtolower(str_replace(' ', '_', $state));
    $form['workflow'][$key] = array(
      '#type' => 'fieldset',
      '#title' => $state,
    );
    $form['workflow'][$key]['reviewboard_notifications_' . $key . '_ou'] = array(
      '#type' => 'radios',
      '#title' => 'OU POC',
      '#description' => "Enabled or disable email notifications for the OU POC when reviews reach the $state state.",
      '#options' => array('Disabled', 'Enabled'),
      '#default_value' => variable_get('reviewboard_notifications_' . $key . '_ou', 0),
    );
    $form['workflow'][$key]['reviewboard_notifications_' . $key . '_ro'] = array(
      '#type' => 'radios',
      '#title' => 'Review office',
      '#description' => "Enabled or disable email notifications for the review office when reviews reach the $state state.",
      '#options' => array('Disabled', 'Enabled'),
      '#default_value' => variable_get('reviewboard_notifications_' . $key . '_ro', 0),
    );
  }
  return system_settings_form($form);
}
/**
 * Form builder; Configure user settings for this site.
 *
 * @ingroup forms
 * @see system_settings_form()
 */
function reviewboard_notifications_email_settings() {
  // User e-mail settings.
  $form['email'] = array(
    '#type' => 'fieldset',
    '#title' => t('Review board workflow notification e-mail settings'),
    '#description' => t('This form is used to alter the standard email subject and body for each notification sent via the review board review status workflow.'),
  );
  // These email tokens are shared for all settings, so just define
  // the list once to help ensure they stay in sync.
  $email_token_help = t('Available variables are:') .' !username, !site, !site_uri, !title, !review_uri, !comment.';

  $form['email']['proposed'] = array(
    '#type' => 'fieldset',
    '#title' => t('Proposed status emails'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['email']['proposed']['ou_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU POC notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_proposed_ou', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the OU POC of a newly created review.') .' '. $email_token_help,
  );
  $form['email']['proposed']['ou_notification']['reviewboard_notifications_proposed_ou_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('proposed_ou_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['proposed']['ou_notification']['reviewboard_notifications_proposed_ou_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('proposed_ou_body'),
    '#rows' => 15,
  );
  $form['email']['proposed']['pmo_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('PMO notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_proposed_ro', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the review office for newly created reviews.') .' '. $email_token_help,
  );
  $form['email']['proposed']['pmo_notification']['reviewboard_notifications_proposed_pmo_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('proposed_ro_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['proposed']['pmo_notification']['reviewboard_notifications_proposed_pmo_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('proposed_ro_body'),
    '#rows' => 15,
  );

  $form['email']['ou_prep'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU prep status emails'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['email']['ou_prep']['ou_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU POC notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_ou_prep_ou', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the OU POC when review reaches the OU prep state.') .' '. $email_token_help,
  );
  $form['email']['ou_prep']['ou_notification']['reviewboard_notifications_ou_prep_ou_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('ou_prep_ou_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['ou_prep']['ou_notification']['reviewboard_notifications_ou_prep_ou_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('ou_prep_ou_body'),
    '#rows' => 15,
  );
  $form['email']['ou_prep']['pmo_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('Review office notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_ou_prep_ro', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the review office when review reaches the OU prep state.') .' '. $email_token_help,
  );
  $form['email']['ou_prep']['pmo_notification']['reviewboard_notifications_ou_prep_pmo_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('ou_prep_ro_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['ou_prep']['pmo_notification']['reviewboard_notifications_ou_prep_pmo_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('ou_prep_ro_body'),
    '#rows' => 15,
  );

  $form['email']['departmental_prep'] = array(
    '#type' => 'fieldset',
    '#title' => t('Departmental prep status emails'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['email']['departmental_prep']['ou_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU POC notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_departmental_prep_ou', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the OU POC when review reaches the departmental prep state.') .' '. $email_token_help,
  );
  $form['email']['departmental_prep']['ou_notification']['reviewboard_notifications_departmental_prep_ou_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('departmental_prep_ou_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['departmental_prep']['ou_notification']['reviewboard_notifications_departmental_prep_ou_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('departmental_prep_ou_body'),
    '#rows' => 15,
  );
  $form['email']['departmental_prep']['pmo_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('Review office notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_departmental_prep_ro', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the review office when review reaches the departmental prep state.') .' '. $email_token_help,
  );
  $form['email']['departmental_prep']['pmo_notification']['reviewboard_notifications_departmental_prep_pmo_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('departmental_prep_ro_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['departmental_prep']['pmo_notification']['reviewboard_notifications_departmental_prep_pmo_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('departmental_prep_ro_body'),
    '#rows' => 15,
  );

  $form['email']['ipt_review'] = array(
    '#type' => 'fieldset',
    '#title' => t('IPT review status emails'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['email']['ipt_review']['ou_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU POC notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_ipt_review_ou', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the OU POC when review reaches the IPT review state.') .' '. $email_token_help,
  );
  $form['email']['ipt_review']['ou_notification']['reviewboard_notifications_ipt_review_ou_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('ipt_review_ou_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['ipt_review']['ou_notification']['reviewboard_notifications_ipt_review_ou_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('ipt_review_ou_body'),
    '#rows' => 15,
  );
  $form['email']['ipt_review']['pmo_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('Review office notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_ipt_review_ro', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the review office when review reaches the IPT review state.') .' '. $email_token_help,
  );
  $form['email']['ipt_review']['pmo_notification']['reviewboard_notifications_ipt_review_pmo_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('ipt_review_ro_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['ipt_review']['pmo_notification']['reviewboard_notifications_ipt_review_pmo_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('ipt_review_ro_body'),
    '#rows' => 15,
  );

  $form['email']['confirmed'] = array(
    '#type' => 'fieldset',
    '#title' => t('Confirmed status emails'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['email']['confirmed']['ou_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU POC notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_confirmed_ou', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the OU POC when review reaches the Confirmed state.') .' '. $email_token_help,
  );
  $form['email']['confirmed']['ou_notification']['reviewboard_notifications_confirmed_ou_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('confirmed_ou_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['confirmed']['ou_notification']['reviewboard_notifications_confirmed_ou_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('confirmed_ou_body'),
    '#rows' => 15,
  );
  $form['email']['confirmed']['pmo_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('Review office notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_confirmed_ro', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the review office when review reaches the confirmed state.') .' '. $email_token_help,
  );
  $form['email']['confirmed']['pmo_notification']['reviewboard_notifications_confirmed_pmo_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('confirmed_ro_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['confirmed']['pmo_notification']['reviewboard_notifications_confirmed_pmo_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('confirmed_ro_body'),
    '#rows' => 15,
  );

  $form['email']['post_review'] = array(
    '#type' => 'fieldset',
    '#title' => t('Post review status emails'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['email']['post_review']['ou_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU POC notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_post_review_ou', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the OU POC when review reaches the post review state.') .' '. $email_token_help,
  );
  $form['email']['post_review']['ou_notification']['reviewboard_notifications_post_review_ou_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('post_review_ou_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['post_review']['ou_notification']['reviewboard_notifications_post_review_ou_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('post_review_ou_body'),
    '#rows' => 15,
  );
  $form['email']['post_review']['pmo_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('Review office notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_post_review_ro', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the review office when review reaches the post review state.') .' '. $email_token_help,
  );
  $form['email']['post_review']['pmo_notification']['reviewboard_notifications_post_review_pmo_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('post_review_ro_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['post_review']['pmo_notification']['reviewboard_notifications_post_review_pmo_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('post_review_ro_body'),
    '#rows' => 15,
  );

  $form['email']['closed'] = array(
    '#type' => 'fieldset',
    '#title' => t('Closed status emails'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );
  $form['email']['closed']['ou_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('OU POC notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_closed_ou', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the OU POC when review reaches the closed state.') .' '. $email_token_help,
  );
  $form['email']['closed']['ou_notification']['reviewboard_notifications_closed_ou_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('closed_ou_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['closed']['ou_notification']['reviewboard_notifications_closed_ou_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('closed_ou_body'),
    '#rows' => 15,
  );
  $form['email']['closed']['pmo_notification'] = array(
    '#type' => 'fieldset',
    '#title' => t('Review office notification'),
    '#collapsible' => TRUE,
    '#collapsed' => (variable_get('reviewboard_notifications_closed_ro', 0) != 1),
    '#description' => t('Customize e-mail messages sent to the review office when review reaches the closed state.') .' '. $email_token_help,
  );
  $form['email']['closed']['pmo_notification']['reviewboard_notifications_closed_pmo_notification_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => reviewboard_notifications_mail_text('closed_ro_subject'),
    '#type' => 'textfield',
    '#maxlength' => 180,
  );
  $form['email']['closed']['pmo_notification']['reviewboard_notifications_closed_pmo_notification_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => reviewboard_notifications_mail_text('closed_ro_body'),
    '#rows' => 15,
  );

  return system_settings_form($form);
}
/**
 *
 * @return
 *   The HTML table with the reminders type list.
 */
function reviewboard_notifications_reminder_settings() {
  ctools_include('export');
  $exportables = ctools_export_load_object('rb_reminders');
  // now we can add the exported data to the $rows array
  foreach ($exportables as $name => $object) {
    $state = '';
    foreach (unserialize($object->sid) as $id => $sid) {
      if ($state) {
        $state .= ', ';
      }
      $array = workflow_get_state($sid);
      $state .= $array['state'];
    }
    $rows[] = array(
      'data' => array(
        $object->period,
        $object->period_def,
        $object->operation,
        $object->date_def,
        $state,
        $object->type,
        l(t('edit'), 'admin/settings/reviewboard/reviewboard_notifications/reminder/edit/'. $object->name, array('query' => array('destination' => 'reviewboard_notifications/reminder'))),
      ),
    );
  }
  $header = array(
    t('Period'),
    t('Period type'),
    t('Op'),
    t('Date'),
    t('States'),
    t('Status'),
    array('data' => t('Operations'), 'colspan' => 2),
  );

  $form['table'] = array('#value' => theme('table', $header, $rows));

  return $form;
}

/**
 * Create or edit email reminders.
 * 
 * @return
 *   The form structure.
 */
function reviewboard_notifications_reminder() {
  $date_def_options = array();
  $date_def_default = '';
  foreach (reviewboard_notifications_reminder_type_list() as $key => $val) {
    $date_def_options[$key] = $key;
    if ($val['default']) {
      $date_def_default = $key;
    }
  }
  $wid = workflow_get_workflow_for_type('review');
  $states = workflow_get_states($wid);
  $states[0] = 'any';
  $args = func_get_args();
  array_shift($args);
    $args[0] = trim(strip_tags($args[0]));
  if ($args[0]) {
    ctools_include('export');
    $exportables = ctools_export_load_object('rb_reminders');
    foreach ($exportables as $key => $object) {
      if ($key == $args[0]) {
        $rid = $object->rid;
        $period = $object->period;
        $period_def = $object->period_def;
        $op = $object->operation;
        $date_def = $object->date_def;
        $state = unserialize($object->sid);
        $name = $object->name;
        $subject = $object->email_subject;
        $body = $object->email_body;
      }
    }
  }
  else {
    $rid = '';
    $name = hash('md5', time() . rand());
  }
  $form['create-options'] = array(
    '#type' => 'fieldset',
    '#title' => t('Define a reminder'),
    '#collapsible' => FALSE,
    '#collapsed' => FALSE,
  );
  $form['create-options']['rid'] = array(
    '#type' => 'hidden',
    '#value' => $rid,
  );
  $form['create-options']['name'] = array(
    '#type' => 'hidden',
    '#value' => $name,
  );
  $form['create-options']['period'] = array(
    '#type' => 'textfield',
    '#title' => t('Time period'),
    '#description' => t('A number.'),
    '#default_value' => ($period?$period:''),
  );
  $form['create-options']['period_def'] = array(
    '#type' => 'select',
    '#title' => t('Choose the time period units'),
    '#description' => t('The units of time to be used in the calculation.'),
//    '#options' => array('seconds' => 'seconds', 'minutes' => 'minutes', 'hours' => 'hours', 'days' => 'days'),
    '#options' => array('days' => 'days'),
    '#default_value' => ($period_def?$period_def:'days'),
  );
  $form['create-options']['operation'] = array(
    '#type' => 'select',
    '#title' => t('Choose the operation to be performed'),
    '#description' => t('The operation for the calculation.  Before, after and on directly translate to < (less than), > (greater than), and = (equals).'),
    '#default_value' => ($op?$op:'before'),
    '#options' => array('before' => 'before', 'after' => 'after', 'on' => 'on'),
    '#required' => TRUE,
  );
  $form['create-options']['date_def'] = array(
    '#type' => 'select',
    '#title' => t('Define the type of date to use'),
    '#description' => t('The date/time to use for comparison to the current date/time.  This defaults to the referenced review date/time.'),
    '#default_value' => ($date_def ? $date_def : $date_def_default),
    '#options' => $date_def_options,
    '#required' => TRUE,
  );
  $form['create-options']['sid'] = array(
    '#type' => 'select',
    '#title' => t('Workflow state'),
    '#description' => t('Select all states where this reminder should be used.'),
    '#multiple' => TRUE,
    '#default_value' => ($state ? $state : 0),
    '#options' => $states,
  );
  // These email tokens are shared for all settings, so just define
  // the list once to help ensure they stay in sync.
  $email_token_help = t('Available variables are:') .' !username, !site, !action, !agency, !date, !site_uri, !workflow_uri, !title, !app_uri.';
  $form['create-options']['email_subject'] = array(
    '#type' => 'textfield',
    '#title' => t('Subject'),
    '#default_value' => $subject ? $subject : 'Reminder:  CITRB review is just around the corner!',
    '#type' => 'textfield',
    '#maxlength' => 180,
    '#description' => $email_token_help,
  );
  $form['create-options']['email_body'] = array(
    '#type' => 'textarea',
    '#title' => t('Body'),
    '#default_value' => $body ? $body : "!username,\n\nYou are receiving this reminder because the CITRB review is in 14 days and we have not received the presentation documents as of yet.  Please upload your documents and send the ticket to the Departmental prep state at your earliest convenience.\nThank you,\n\nOCIO PMO",
    '#rows' => 15,
    '#description' => $email_token_help,
  );
  $form['submit'] = array(
    '#type'  => 'submit',
    '#value' => t('Save'),
  );
  $form['reset'] = array(
    '#type'  => 'submit',
    '#value' => t('Reset'),
  );
  return $form;
}

/**
 * Validate hook for the settings form.
 */
function reviewboard_notifications_reminder_validate($form, &$form_state) {
  if ($form_state['clicked_button']['#value'] == 'Reset') {
        unset($form_state);
        drupal_goto('admin/settings/reminder/add');
  }
}
/**
 * Submit hook for the settings form.
 */
function reviewboard_notifications_reminder_submit($form, &$form_state) {
  $op = $form_state['clicked_button']['#value'];
  $values = $form_state['values'];
  $record = new stdClass();
  $record->period = $values['period'];
  $record->period_def = $values['period_def'];
  $record->operation = $values['operation'];
  $record->date_def = $values['date_def'];
  $record->sid = serialize($values['sid']);
  $record->email_subject = $values['email_subject'];
  $record->email_body = $values['email_body'];
//print_r($form_state['values']);
  switch ($op) {
    case t('Save'):
      if ($values['rid']) {
        $record->rid = $values['rid'];
        drupal_write_record('rb_reminders', $record, 'rid');
      } else {
        // this is a new record so we need to set a unique name
        $record->name = $values['name'];
        drupal_write_record('rb_reminders', $record);
      }
      drupal_set_message(t('The reminder has been saved.'));
      break;
    case t('Reset'):
      unset($form_state);
      break;
  }

}

